@@ -14,8 +14,13 @@ import json
 import os
 
 
+_AWS_SESSION = None
 
-session = boto3.Session(profile_name='default') # use default aws session (session is stored in  ~/.aws/credentials)
+def get_aws_session():
+    global _AWS_SESSION
+    if _AWS_SESSION is None:
+        _AWS_SESSION = boto3.Session(profile_name='production-developer') # UPDATE: 02-19-2021, change to use prod-dev ased on last change in okta scripts. aws session (session is stored in  ~/.aws/credentials)
+    return _AWS_SESSION
 
 def rsa_signer(message):
     if (os.environ.get('CLOUDFRONT') and os.environ.get('CLOUDFRONT_KEY')):
@@ -67,8 +72,7 @@ def get_db_connection():
     if (os.environ.get('MONGODB_URI') and os.environ.get('MONGODB_DB') and os.environ.get('MONGODB_CONNECTION')):
         MONGODB_URI = get_secret(os.environ.get('MONGODB_URI'))
         MONGODB_DB = os.environ.get('MONGODB_DB')
-        # probably this way to connect to the DB is too hardcoded, we may want to refactor it
-        uri = f"{json.loads(MONGODB_URI)['MONGODB_URI_READ_ONLY'].split(',')[0]}/{os.environ.get('MONGODB_CONNECTION')}"
+        uri = f"{json.loads(MONGODB_URI)['MONGODB_URI_READ_ONLY']}"
         client = MongoClient(uri)
         db = getattr(client, MONGODB_DB)
         return db
@@ -81,6 +85,7 @@ def get_db_connection():
 def get_secret(secret_name):
     region_name = "us-west-2"
     # Create a Secrets Manager client
+    session = get_aws_session()
     client = session.client(
         service_name='secretsmanager',
         region_name=region_name
