@@ -13,11 +13,11 @@ class DebugLidarScene(LidarScene):
     '''
         New Viewer method using open3d, this will work with python 3.7
     '''
-    def preview(self, frame_id=None, file=None):
+    def preview(self, frame_id=None, file=None, aggregated_frames=10):
         if file:
             np.save(file, self.get_all_world_points())
         else:
-            return open_new_viewer(self.get_all_world_points())
+            return open_new_viewer(self.get_all_world_points(), aggregated_frames)
 
     def get_all_world_points(self):
         all_points = []
